@@ -32,38 +32,47 @@ sub attach_db {
         my $h_ref = $ax->read_json( $sf->{i}{f_attached_db} ) // {};
         $cur_attached = $h_ref->{$sf->{d}{db}} // [];
     }
-    my $choices = [ undef, @{$sf->{d}{user_dbs}}, @{$sf->{d}{sys_dbs}} ];
     my $new_attached = [];
+    my $old_idx = 1;
 
     ATTACH: while ( 1 ) {
 
         DB: while ( 1 ) {
-            my @tmp_info = ( $sf->{d}{db_string} );
+            my @info = ( $sf->{d}{db_string} );
             for my $ref ( @$cur_attached, @$new_attached ) {
-                push @tmp_info, sprintf "ATTACH DATABASE %s AS %s", @$ref;
+                push @info, sprintf "ATTACH DATABASE %s AS %s", @$ref;
             }
-            push @tmp_info, '';
-            my $info = join( "\n", @tmp_info );
-            my $prompt = "ATTACH DATABASE";
+            push @info, '';
+            my @pre = ( undef );
+            my @choices = ( @{$sf->{d}{user_dbs}}, @{$sf->{d}{sys_dbs}} );
+            my $menu = [ @pre, @choices ];
             # Choose
-            my $db = $tc->choose(
-                $choices,
-                { %{$sf->{i}{lyt_v_clear}}, prompt => $prompt, info => $info, undef => $sf->{i}{back} }
+            my $idx = $tc->choose(
+                $menu,
+                { %{$sf->{i}{lyt_v_clear}}, prompt => "ATTACH DATABASE", info => join( "\n", @info ),
+                  undef => $sf->{i}{back}, index => 1, default => $old_idx }
             );
-            if ( ! defined $db ) {
+            if ( ! defined $idx || ! defined $menu->[$idx] ) {
                 if ( @$new_attached ) {
                     shift @$new_attached;
                     next DB;
                 }
                 return;
             }
+            if ( $sf->{o}{G}{menu_memory} ) {
+                if ( $old_idx == $idx && ! $ENV{TC_RESET_AUTO_UP} ) {
+                    $old_idx = 0;
+                    next ATTACH;
+                }
+                $old_idx = $idx;
+            }
+            my $db = $menu->[$idx];
             my $tf = Term::Form->new( $sf->{i}{tf_default} );
-            push @tmp_info, "ATTACH DATABASE $db AS";
-            $info = join( "\n", @tmp_info );
+            push @info, "ATTACH DATABASE $db AS";
 
             ALIAS: while ( 1 ) {
                 my $alias = $tf->readline( 'alias: ',
-                    { info => $info, clear_screen => 1 }
+                    { info => join( "\n", @info ), clear_screen => 1 }
                 );
                 if ( ! length $alias ) {
                     last ALIAS;
@@ -73,7 +82,7 @@ sub attach_db {
                     # Choose
                     my $retry = $tc->choose(
                         [ undef, 'New alias' ],
-                        { prompt => $prompt, info => $info, undef => $sf->{i}{back}, clear_screen => 1 }
+                        { prompt => $prompt, info => join( "\n", @info ), undef => $sf->{i}{back}, clear_screen => 1 }
                     );
                     last ALIAS if ! defined $retry;
                     next ALIAS;
@@ -85,15 +94,14 @@ sub attach_db {
             }
 
             POP_ATTACHED: while ( 1 ) {
-                my @tmp_info = ( $sf->{d}{db_string} );
-                push @tmp_info, map { "ATTACH DATABASE $_->[0] AS $_->[1]" } @$cur_attached, @$new_attached;
-                push @tmp_info, '';
-                my $info = join( "\n", @tmp_info );
+                my @info = ( $sf->{d}{db_string} );
+                push @info, map { "ATTACH DATABASE $_->[0] AS $_->[1]" } @$cur_attached, @$new_attached;
+                push @info, '';
                 my ( $ok, $more ) = ( 'OK', '++' );
                 # Choose
                 my $choice = $tc->choose(
                     [ undef, $ok, $more ],
-                    { info => $info, clear_screen => 1 }
+                    { info => join( "\n", @info ), clear_screen => 1 }
                 );
                 if ( ! defined $choice ) {
                     if ( @$new_attached > 1 ) {
