@@ -83,11 +83,11 @@ sub create_view {
             }
             $ax->print_sql( $sql );
             my $prompt = "$sql->{table} already exists.";
-            my $choice = $tc->choose(
+            my $chosen = $tc->choose(
                 [ undef, '  New name' ],
                 { %{$sf->{i}{lyt_v}}, prompt => $prompt }
             );
-            if ( ! defined $choice ) {
+            if ( ! defined $chosen ) {
                 return;
             }
             next VIEW_NAME;
@@ -196,7 +196,7 @@ sub __create {
     # Choose
     my $create_table_ok = $tc->choose(
         [ undef, $yes, $no ],
-        { %{$sf->{i}{lyt_v}}, prompt => $prompt, undef => '  ' . $sf->{i}{back} }
+        { %{$sf->{i}{lyt_v}}, prompt => $prompt, undef => '  <=' }
     );
     if ( ! defined $create_table_ok ) {
         return;
@@ -274,11 +274,11 @@ sub __set_table_name {
         $sf->{i}{occupied_term_height} = 3;
         $ax->print_sql( $sql );
         my $prompt = "Table $sql->{table} already exists.";
-        my $choice = $tc->choose(
+        my $chosen = $tc->choose(
             [ undef, '  New name' ],
             { %{$sf->{i}{lyt_v}}, prompt => $prompt }
         );
-        if ( ! defined $choice ) {
+        if ( ! defined $chosen ) {
             return;
         }
     }
@@ -318,10 +318,11 @@ sub __set_columns {
                 my $ok_names = $sf->__column_names( $sql );
                 if ( ! $ok_names ) {
                     $sql->{create_table_cols} = [ @bu_create_table_cols ];
-                    next AI_COL;
+                    next AI_COL if $sf->{col_auto};
+                    next HEADER_ROW;
                 }
-                $ax->print_sql( $sql );
                 if ( any { ! length } @{$sql->{create_table_cols}} ) {
+                    # Choose
                     $tc->choose(
                         [ 'Column with no name!' ],
                         { prompt => 'Continue with ENTER' }
@@ -330,6 +331,7 @@ sub __set_columns {
                 }
                 my @duplicates = duplicates map { lc } @{$sql->{create_table_cols}};
                 if ( @duplicates ) {
+                    # Choose
                     $tc->choose(
                         [ 'Duplicate column name!' ],
                         { prompt => 'Continue with ENTER' }
@@ -362,25 +364,56 @@ sub __header_row {
     my ( $sf, $sql ) = @_;
     my $tc = Term::Choose->new( $sf->{i}{tc_default} );
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
+    my ( $first_row,        $user_input        ) = ( '- YES',                   '- NO'                   );
+    my ( $first_row_edited, $user_input_edited ) = ( '- YES, edited as before', '- NO, edited as before' );                 #
+    my @pre = ( undef );
+    my $menu = [ @pre, $first_row, $user_input ];
+    my $prev_edited_header;                                                                                                 #
+    if ( exists $sf->{i}{ct}{prev_header_info} ) {                                                                          #
+        ( my $prev_orig_header, $prev_edited_header, my $header_is_first_data_row ) = @{$sf->{i}{ct}{prev_header_info}};    #
+        if ( $header_is_first_data_row ) {                                                                                  #
+            my $add_to_menu = 1;                                                                                            #
+            for my $i ( 0 .. $#$prev_orig_header ) {                                                                        #
+                if ( $prev_orig_header->[$i] ne $sql->{insert_into_args}[0][$i] ) {                                         #
+                    $add_to_menu = 0;                                                                                       #
+                    last;                                                                                                   #
+                }                                                                                                           #
+            }                                                                                                               #
+            if ( $add_to_menu ) {                                                                                           #
+                splice @$menu, 2, 0, $first_row_edited;                                                                     #
+            }                                                                                                               #
+        }                                                                                                                   #
+        else {                                                                                                              #
+            if ( @$prev_orig_header == @{$sql->{insert_into_args}[0]} ) {                                                   #
+                push @$menu, $user_input_edited;                                                                            #
+            }                                                                                                               #
+        }                                                                                                                   #
+    }                                                                                                                       #
     my $header_row;
-    my ( $first_row, $user_input ) = ( '- First row', '- Set temp column names' );
     $sf->{i}{occupied_term_height} = 4;
     $ax->print_sql( $sql );
     # Choose
-    my $choice = $tc->choose(
-        [ undef, $first_row, $user_input ],
-        { %{$sf->{i}{lyt_v}}, prompt => 'Column names:' } # 'Header:'
+    my $chosen = $tc->choose(
+        $menu,
+        { %{$sf->{i}{lyt_v}}, prompt => 'Use the first Data Row as the Table Header:', undef => '  <=' }
     );
-    if ( ! defined $choice ) {
+    if ( ! defined $chosen ) {
         return;
     }
-    elsif ( $choice eq $first_row ) {
-        $header_row = shift @{$sql->{insert_into_args}};
-        $sf->{i}{ct}{shifted_header} = $header_row;
+    elsif ( $chosen eq $first_row ) {
+        $sf->{i}{ct}{shifted_header} = shift @{$sql->{insert_into_args}};
+        $header_row = [ @{$sf->{i}{ct}{shifted_header}} ];
     }
+    elsif ( $chosen eq $first_row_edited ) {                                #
+        $sf->{i}{ct}{shifted_header} = shift @{$sql->{insert_into_args}};   #
+        $header_row = $prev_edited_header;                                  #
+    }                                                                       #
+    elsif ( $chosen eq $user_input_edited ) {                               #
+        $header_row = $prev_edited_header;                                  #
+    }                                                                       #
     else {
         my $c = 0;
-        $header_row = [ map { 'c' . ++$c } @{$sql->{insert_into_args}->[0]} ];
+        $header_row = $sf->__generic_header_row( scalar @{$sql->{insert_into_args}->[0]} );
     }
     return $header_row;
 }
@@ -400,14 +433,14 @@ sub __autoincrement_column {
         $sf->{i}{occupied_term_height} = 4;
         $ax->print_sql( $sql );
         # Choose
-        my $choice = $tc->choose(
+        my $chosen = $tc->choose(
             [ undef, $yes, $no  ],
-            { %{$sf->{i}{lyt_v}}, prompt => 'Add AUTO INCREMENT column:',  }
+            { %{$sf->{i}{lyt_v}}, prompt => 'Add an AUTO INCREMENT column:', undef => '  <='  }
         );
-        if ( ! defined $choice ) {
+        if ( ! defined $chosen ) {
             return;
         }
-        elsif ( $choice eq $no ) {
+        elsif ( $chosen eq $no ) {
             $sf->{col_auto} = '';
         }
         else {
@@ -422,17 +455,44 @@ sub __column_names {
     my $tf = Term::Form->new( $sf->{i}{tf_default} );
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
     my $col_number = 0;
+    my $db = $sf->{d}{db};
     my $fields = [ map { [ ++$col_number, defined $_ ? "$_" : '' ] } @{$sql->{create_table_cols}} ];
     $sf->{i}{occupied_term_height} = 3 + @{$sql->{create_table_cols}};
     $ax->print_sql( $sql );
     # Fill_form
     my $form = $tf->fill_form(
         $fields,
-        { prompt => 'Edit column names:', auto_up => 2, confirm => $sf->{i}{_confirm}, back => $sf->{i}{_back} . '   ' }
+        { prompt => 'Edit column names:', auto_up => 2, confirm => $sf->{i}{confirm}, back => $sf->{i}{back} . '   ' }
     );
-    if ( ! $form ) {
+    if ( ! defined $form ) {
         return;
     }
+    my ( $orig_header, $header_is_first_data_row );                                                     #
+    if ( exists $sf->{i}{ct}{shifted_header} ) {                                                        #
+        $orig_header = [ @{$sf->{i}{ct}{shifted_header}} ];                                             #
+        $header_is_first_data_row = 1;                                                                  #
+    }                                                                                                   #
+    else {                                                                                              #
+        $orig_header = $sf->__generic_header_row( scalar @{$sql->{insert_into_args}->[0]} );            #
+        $header_is_first_data_row = 0;                                                                  #
+    }                                                                                                   #
+    my $edited_header = [ map { $_->[1] } @$form ];                                                     #
+    if ( length $sf->{col_auto} ) {                                                                     #
+        shift @$edited_header;                                                                          #
+    }                                                                                                   #
+    my $diff_between_orig_and_edited_header = 0;                                                        #
+    for my $i ( 0 .. $#$orig_header ) {                                                                 #
+        if ( $orig_header->[$i] ne $edited_header->[$i] ) {                                             #
+            $diff_between_orig_and_edited_header = 1;                                                   #
+            last;                                                                                       #
+        }                                                                                               #
+    }                                                                                                   #
+    if ( $diff_between_orig_and_edited_header ) {                                                       #
+        $sf->{i}{ct}{prev_header_info} = [ $orig_header, $edited_header, $header_is_first_data_row ];   #
+    }                                                                                                   #
+    elsif ( exists $sf->{i}{ct}{prev_header_info} ) {                                                   #
+        delete $sf->{i}{ct}{prev_header_info};                                                          #
+    }                                                                                                   #
     $sql->{create_table_cols} = [ map { $_->[1] } @$form ]; # not quoted
     if ( length $sf->{col_auto} ) {
         $sf->{col_auto} = $sql->{create_table_cols}[0];
@@ -440,10 +500,17 @@ sub __column_names {
     return 1;
 }
 
+sub __generic_header_row {
+    my ( $sf, $col_count ) = @_;
+    my $c = 0;
+    return [ map { 'c' . $c++ } 1 .. $col_count ];
+}
+
 sub __data_types {
     my ( $sf, $sql ) = @_;
     my $tf = Term::Form->new( $sf->{i}{tf_default} );
     my $ax = App::DBBrowser::Auxil->new( $sf->{i}, $sf->{o}, $sf->{d} );
+    my $unquoted_table_cols = [ @{$sql->{create_table_cols}} ];
     $sql->{create_table_cols} = $ax->quote_simple_many( $sql->{create_table_cols} ); # now quoted
     $sql->{insert_into_cols} = [ @{$sql->{create_table_cols}} ];
     if ( length $sf->{col_auto} ) {
@@ -452,6 +519,7 @@ sub __data_types {
     my $data_types;
     my $fields;
     if ( $sf->{o}{create}{data_type_guessing} ) {
+        $sf->{i}{occupied_term_height} = 1;
         $ax->print_sql( $sql, 'Guessing data types ... ' );
         $data_types = $sf->__guess_data_type( $sql );
     }
@@ -466,24 +534,31 @@ sub __data_types {
         unshift @$fields, [ $ax->quote_col_qualified( [ $sf->{col_auto} ] ), $sf->{constraint_auto} ];
         $read_only = [ 0 ];
     }
-    $sf->{i}{occupied_term_height} = 3 + @$fields;
-    $ax->print_sql( $sql );
-    # Fill_form
-    my $col_name_and_type = $tf->fill_form(
-        $fields,
-        { prompt => 'Data types:', auto_up => 2, read_only => $read_only, confirm => $sf->{i}{_confirm},
-          back => $sf->{i}{_back} . '   ' }
-    );
-    if ( ! $col_name_and_type ) {
-        return;
-    }
-    {
-        no warnings 'uninitialized';
-        $sql->{create_table_cols} = [ map { join ' ', @$_ }  @$col_name_and_type ];
+    my $db = $sf->{d}{db};
+    my $col_name_and_type;
+
+    while ( 1 ) {
+        $sf->{i}{occupied_term_height} = 3 + @$fields; # prompt, back, confirm and fiels
+        $ax->print_sql( $sql );
+        # Fill_form
+        $col_name_and_type = $tf->fill_form(
+            $fields,
+            { prompt => 'Column data types:', auto_up => 2, read_only => $read_only, confirm => $sf->{i}{confirm},
+            back => $sf->{i}{back} . '   ' }
+        );
+        if ( ! $col_name_and_type ) {
+            return;
+        }
+        else {
+            no warnings 'uninitialized';
+            $sql->{create_table_cols} = [ map { join ' ', @$_ }  @$col_name_and_type ];
+            last;
+        }
     }
     return 1;
 }
 
+
 sub __guess_data_type {
     my ( $sf, $sql ) = @_;
     require SQL::Type::Guess;
